@@ -1,4 +1,4 @@
-/* WMix 3.2 -- a mixer using the OSS mixer API.
+/* WMix 3.0 -- a mixer using the OSS mixer API.
  * Copyright (C) 2000, 2001
  *	Daniel Richard G. <skunk@mit.edu>,
  *	timecop <timecop@japan.co.jp>
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 typedef unsigned int bool;
@@ -33,19 +33,11 @@ typedef unsigned int bool;
 #define CLAMP(x, low, high) (((x) > (high)) ? (high) : (((x) < (low)) ? (low) : (x)))
 
 #define MAX_DOUBLE_CLICK_TIME 0.5
-#define BUTTON_WHEEL_UP 4
-#define BUTTON_WHEEL_DOWN 5
 
-typedef struct _Config Config;
-
-struct _Config {
-    char 	*file;			/* full path to config file name */
-    unsigned int osd        : 1;	/* show OSD? */
-    unsigned int mousewheel : 1;	/* mousewheel enabled? */
-    unsigned int scrolltext : 1;	/* scroll channel names? */
-    unsigned int wheel_button_up;	/* up button */
-    unsigned int wheel_button_down;	/* down button */
-    unsigned int lcd        : 1;	/* default display mode - lcd */
-    float	 scrollstep;		/* scroll mouse step adjustment */
-    char	*osd_color;		/* osd color */
-};
+/*
+ * Get the number of element in a static array
+ *
+ * Do not use on an allocated array, it will not work
+ */
+#define lengthof(arr)  \
+	((ssize_t)(sizeof( arr ) / sizeof( arr[0] )))
